<%page args="b" /> <%! from stoqlib.lib.formatters import (get_formatted_price, get_price_as_cardinal, get_full_date) f_currency = get_formatted_price f_currency_full = get_price_as_cardinal f_date = lambda d: d.strftime('%x') f_date_full = get_full_date %>

# ${ _("Promissory Note") }

## ${ _("Payment local") }

% if b.drawer_document == '': ${ b.drawer }
% else: ${ "%s - %s" % (b.drawer, b.drawer_document) }
% endif ${ b.drawer_address[0] }
${ b.drawer_address[1] }

## ${ _("Issuer") }

% if b.drawee_document == '': ${ b.drawee }
% else: ${ "%s - %s" % (b.drawee, b.drawee_document) }
% endif ${ b.drawee_address[0] }
${ b.drawee_address[1] }

${ _("Number:") } | % if b.payment_number and b.order_identifier: ${ "%s / %s" % (b.order_identifier, b.payment_number) } % elif b.payment_number: ${ b.payment_number } % elif b.order_identifier: ${ b.order_identifier } % endif
${ _("Emission date:") } | ${ f_date_full(b.emission_date) }
${ _("Due date:") } | ${ f_date_full(b.due_date) }
${ _("Value:") } | ${ f_currency(b.value) }